@@ -17,11 +17,12 @@ __date__ = "Sep 23, 2011"
 import math
 import numpy as np
 import itertools
+import collections
 
 from pymatgen.command_line.qhull_caller import qvoronoi, qvertex
 
 
-class VoronoiCoordFinder:
+class VoronoiCoordFinder(object):
     """
     Uses a Voronoi algorithm to determine the coordination for each site in a
     structure.
@@ -127,6 +128,82 @@ class VoronoiCoordFinder:
         return coordinated_sites
 
 
+class RelaxationAnalyzer(object):
+    """
+    This class analyzes the relaxation in a calculation.
+    """
+
+    def __init__(self, initial_structure, final_structure):
+        """
+        Please note that the input and final structures should have the same
+        ordering of sites. This is typically the case for most computational
+        codes.
+
+        Args:
+            initial_structure:
+                Initial input structure to calculation.
+            final_structure:
+                Final output structure from calculation.
+        """
+        if final_structure.formula != initial_structure.formula:
+            raise ValueError("Initial and final structures have different " +
+                             "formulas!")
+        self.initial = initial_structure
+        self.final = final_structure
+
+    def get_percentage_volume_change(self):
+        """
+        Returns the percentage volume change.
+
+        Returns:
+            Volume change in percentage, e.g., 0.055 implies a 5.5% increase.
+        """
+        initial_vol = self.initial.lattice.volume
+        final_vol = self.final.lattice.volume
+        return final_vol / initial_vol - 1
+
+    def get_percentage_lattice_parameter_changes(self):
+        """
+        Returns the percentage lattice parameter changes.
+
+        Returns:
+            A dict of the percentage change in lattice parameter, e.g.,
+            {'a': 0.012, 'b': 0.021, 'c': -0.031} implies a change of 1.2%,
+            2.1% and -3.1% in the a, b and c lattice parameters respectively.
+        """
+        initial_latt = self.initial.lattice
+        final_latt = self.final.lattice
+        d = {l: getattr(final_latt, l) / getattr(initial_latt, l) - 1
+             for l in ["a", "b", "c"]}
+        return d
+
+    def get_percentage_bond_dist_changes(self, max_radius=3.0):
+        """
+        Returns the percentage bond distance changes for each site up to a
+        maximum radius for nearest neighbors.
+
+        Args:
+            max_radius:
+                Maximum radius to search for nearest neighbors. This radius is
+                applied to the initial structure, not the final structure.
+
+        Returns:
+            Bond distance changes as a dict of dicts. E.g.,
+            {index1: {index2: 0.011, ...}}. For economy of representation, the
+            index1 is always less than index2, i.e., since bonding between
+            site1 and siten is the same as bonding between siten and site1,
+            there is no reason to duplicate the information or computation.
+        """
+        data = collections.defaultdict(dict)
+        for inds in itertools.combinations(xrange(len(self.initial)), 2):
+            (i, j) = sorted(inds)
+            initial_dist = self.initial[i].distance(self.initial[j])
+            if initial_dist < max_radius:
+                final_dist = self.final[i].distance(self.final[j])
+                data[i][j] = final_dist / initial_dist - 1
+        return data
+
+
 def solid_angle(center, coords):
     """
     Helper method to calculate the solid angle of a set of coords from the
