@@ -527,10 +527,9 @@ class Specie(MSONable):
                 {"spin":5}. Defaults to None. Properties must be one of the
                 Specie supported_properties.
         """
-        object.__setattr__(self, "_el", Element(symbol))
-        object.__setattr__(self, "_oxi_state", oxidation_state)
-        object.__setattr__(self, "_properties",
-                           properties if properties else {})
+        self._el = Element(symbol)
+        self._oxi_state = oxidation_state
+        self._properties = properties if properties else {}
         for k in self._properties.keys():
             if k not in Specie.supported_properties:
                 raise ValueError("{} is not a supported property".format(k))
@@ -543,14 +542,6 @@ class Specie(MSONable):
         except:
             raise AttributeError(a)
 
-    def __setattr__(self, n, v):
-        raise ValueError("Specie is immutable and setting of attributes is not"
-                         " allowed")
-
-    def __delattr__(self, n):
-        raise ValueError("Specie is immutable and deleting of attributes is "
-                         "not allowed")
-
     def __eq__(self, other):
         """
         Specie is equal to other only if element and oxidation states are
@@ -678,10 +669,9 @@ class DummySpecie(Specie, MSONable):
         Set required attributes for DummySpecie to function like a Specie in
         most instances.
         """
-        object.__setattr__(self, "_symbol", symbol)
-        object.__setattr__(self, "_oxi_state", oxidation_state)
-        object.__setattr__(self, "_properties",
-                           properties if properties else {})
+        self._symbol = symbol
+        self._oxi_state = oxidation_state
+        self._properties = properties if properties else {}
         for k in self._properties.keys():
             if k not in Specie.supported_properties:
                 raise ValueError("{} is not a supported property".format(k))
