@@ -66,8 +66,8 @@ class IdentityTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "init_args": {},
              "version": __version__}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -120,8 +120,8 @@ class RotationTransformation(AbstractTransformation):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"axis": self._axis, "angle": self._angle,
                           "angle_in_radians": self._angle_in_radians}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -155,8 +155,8 @@ class OxidationStateDecorationTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"oxidation_states": self.oxi_states}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -181,8 +181,8 @@ class OxidationStateRemovalTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -245,8 +245,8 @@ class SupercellTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"scaling_matrix": self._matrix}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -300,8 +300,8 @@ class SubstitutionTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"species_map": self._species_map}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -341,8 +341,8 @@ class RemoveSpeciesTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"species_to_remove": self._species}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -355,34 +355,14 @@ class PartialRemoveSpecieTransformation(AbstractTransformation):
 
     Given that the solution to selecting the right removals is NP-hard, there
     are several algorithms provided with varying degrees of accuracy and speed.
-    The options are as follows:
-
-    ALGO_FAST:
-        This is a highly optimized algorithm to quickly go through the search
-        tree. It is guaranteed to find the optimal solution, but will return
-        only a single lowest energy structure. Typically, you will want to use
-        this.
-
-    ALGO_COMPLETE:
-        The complete algo ensures that you get all symmetrically distinct
-        orderings, ranked by the estimated Ewald energy. But this can be an
-        extremely time-consuming process if the number of possible orderings is
-        very large. Use this if you really want all possible orderings. If you
-        want just the lowest energy ordering, ALGO_FAST is accurate and faster.
-
-    ALGO_BEST_FIRST:
-        This algorithm is for ordering the really large cells that defeats even
-        ALGO_FAST.  For example, if you have 48 sites of which you want to
-        remove 16 of them, the number of possible orderings is around
-        2 x 10^12. ALGO_BEST_FIRST shortcircuits the entire search tree by
-        removing the highest energy site first, then followed by the next
-        highest energy site, and so on.  It is guaranteed to find a solution
-        in a reasonable time, but it is also likely to be highly inaccurate.
+    Please see
+    :class:`pymatgen.transformations.site_transformations.PartialRemoveSitesTransformation`.
     """
 
     ALGO_FAST = 0
     ALGO_COMPLETE = 1
     ALGO_BEST_FIRST = 2
+    ALGO_ENUMERATE = 3
 
     def __init__(self, specie_to_remove, fraction_to_remove, algo=ALGO_FAST):
         """
@@ -453,8 +433,8 @@ class PartialRemoveSpecieTransformation(AbstractTransformation):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"specie_to_remove": self._specie,
                           "fraction_to_remove": self._frac, "algo": self._algo}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -669,8 +649,8 @@ class OrderDisorderedStructureTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"algo": self._algo}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
     @property
@@ -848,8 +828,8 @@ class PrimitiveCellTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
 
 
@@ -892,6 +872,6 @@ class PerturbStructureTransformation(AbstractTransformation):
     def to_dict(self):
         d = {"name": self.__class__.__name__, "version": __version__}
         d["init_args"] = {"amplitude": self._amp}
-        d["module"] = self.__class__.__module__
-        d["class"] = self.__class__.__name__
+        d["@module"] = self.__class__.__module__
+        d["@class"] = self.__class__.__name__
         return d
